Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3767)

Unified Diff: chrome/browser/ui/ash/launcher/chrome_launcher_controller_per_app.h

Issue 11451019: Remove TabContents from ui/ash. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: fix Created 8 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/ash/launcher/chrome_launcher_controller_per_app.h
diff --git a/chrome/browser/ui/ash/launcher/chrome_launcher_controller_per_app.h b/chrome/browser/ui/ash/launcher/chrome_launcher_controller_per_app.h
index 14849ca168b0c8ad04b6653044bd6caffbfab28f..3ddf7428da1d5c0e362e81143c3d3aa4c94247ee 100644
--- a/chrome/browser/ui/ash/launcher/chrome_launcher_controller_per_app.h
+++ b/chrome/browser/ui/ash/launcher/chrome_launcher_controller_per_app.h
@@ -31,7 +31,6 @@ class BrowserLauncherItemControllerTest;
class LauncherItemController;
class Profile;
class ShellWindowLauncherController;
-class TabContents;
namespace ash {
class LauncherModel;
@@ -204,7 +203,7 @@ class ChromeLauncherControllerPerApp
aura::RootWindow* root_window) OVERRIDE;
// The tab no longer represents its previously identified application.
- virtual void RemoveTabFromRunningApp(TabContents* tab,
+ virtual void RemoveTabFromRunningApp(content::WebContents* tab,
const std::string& app_id) OVERRIDE;
// Notify the controller that the state of an non platform app's tabs
@@ -274,9 +273,9 @@ class ChromeLauncherControllerPerApp
typedef std::map<ash::LauncherID, LauncherItemController*>
IDToItemControllerMap;
- typedef std::list<TabContents*> TabContentsList;
- typedef std::map<std::string, TabContentsList> AppIDToTabContentsListMap;
- typedef std::map<TabContents*, std::string> TabContentsToAppIDMap;
+ typedef std::list<content::WebContents*> WebContentsList;
+ typedef std::map<std::string, WebContentsList> AppIDToWebContentsListMap;
+ typedef std::map<content::WebContents*, std::string> WebContentsToAppIDMap;
// Returns the profile used for new windows.
Profile* GetProfileForNewWindows();
@@ -302,8 +301,8 @@ class ChromeLauncherControllerPerApp
// Sets the shelf alignment from prefs.
void SetShelfAlignmentFromPrefs();
- // Returns the most recently active tab contents for an app.
- TabContents* GetLastActiveTabContents(const std::string& app_id);
+ // Returns the most recently active web contents for an app.
+ content::WebContents* GetLastActiveWebContents(const std::string& app_id);
// Creates an app launcher to insert at |index|. Note that |index| may be
// adjusted by the model to meet ordering constraints.
@@ -323,11 +322,11 @@ class ChromeLauncherControllerPerApp
IDToItemControllerMap id_to_item_controller_map_;
- // Maintains activation order of tab contents for each app.
- AppIDToTabContentsListMap app_id_to_tab_contents_list_;
+ // Maintains activation order of web contents for each app.
+ AppIDToWebContentsListMap app_id_to_web_contents_list_;
- // Direct access to app_id for a tab contents.
- TabContentsToAppIDMap tab_contents_to_app_id_;
+ // Direct access to app_id for a web contents.
+ WebContentsToAppIDMap web_contents_to_app_id_;
// Used to track shell windows.
scoped_ptr<ShellWindowLauncherController> shell_window_controller_;

Powered by Google App Engine
This is Rietveld 408576698